==> icinga-web2-2.7.3p0.tgz: icinga-web2/README.md <==
# Icinga Web 2

[![Build Status](https://travis-ci.org/Icinga/icingaweb2.png?branch=master)](https://travis-ci.org/Icinga/icingaweb2)
[![Github Tag](https://img.shields.io/github/tag/Icinga/icingaweb2.svg)](https://github.com/Icinga/icingaweb2)

![Icinga Logo](https://icinga.com/wp-content/uploads/2014/06/icinga_logo.png)

1. [About](#about)
2. [License](#license)
3. [Installation](#installation)
4. [Documentation](#documentation)
5. [Support](#support)
6. [Contributing](#contributing)

## About

**Icinga Web 2** is the next generation open source monitoring web interface, framework
and command-line interface developed by the [Icinga Project](https://icinga.com/), supporting Icinga 2,
Icinga Core and any other monitoring backend compatible with the IDO database.

![Icinga Web 2 with Graphite](https://icinga.com/wp-content/uploads/2017/11/Icinga-Web-2-graphite.png "Icinga Web 2 with Graphite")
![Icinga Web 2 Sidebar Collapsed](https://icinga.com/wp-content/uploads/2017/11/Icinga-Web-2-collapsed-sidebar.png "Icinga Web 2 Sidebar Collapsed")

## License

Icinga Web 2 and the Icinga Web 2 documentation are licensed under the terms of the GNU
General Public License Version 2, you will find a copy of this license in the
COPYING file included in the source package.

## Installation

For installing Icinga Web 2 please check the [installation chapter](https://icinga.com/docs/icingaweb2/latest/doc/02-Installation/)
in the documentation.

## Documentation

The documentation is located in the [doc/](doc/) directory and also available
on [icinga.com/docs](https://icinga.com/docs/icingaweb2/latest/).

## Support

Check the [project website](https://icinga.com) for status updates. Join the
[community channels](https://icinga.com/community/) for questions
or ask an Icinga partner for [professional support](https://icinga.com/support/).

## Contributing

There are many ways to contribute to Icinga -- whether it be sending patches,
testing, reporting bugs, or reviewing and updating the documentation. Every
contribution is appreciated!

Please continue reading in the [contributing chapter](CONTRIBUTING.md).

### Security Issues

For reporting security issues please visit [this page](https://icinga.com/contact/security/).

==> icinga-web2-2.10.0.tgz: icinga-web2/README.md <==
# Icinga Web 2

[![PHP Support](https://img.shields.io/badge/php-%3E%3D%205.6-777BB4?logo=PHP)](https://php.net/)
![Build Status](https://github.com/icinga/icingaweb2/workflows/PHP%20Tests/badge.svg?branch=master)
[![Github Tag](https://img.shields.io/github/tag/Icinga/icingaweb2.svg)](https://github.com/Icinga/icingaweb2)

![Icinga Logo](https://icinga.com/wp-content/uploads/2014/06/icinga_logo.png)

1. [About](#about)
2. [License](#license)
3. [Installation](#installation)
4. [Documentation](#documentation)
5. [Support](#support)
6. [Contributing](#contributing)

## About

**Icinga Web 2** is the next generation open source monitoring web interface, framework
and command-line interface developed by the [Icinga Project](https://icinga.com/), supporting Icinga 2,
Icinga Core and any other monitoring backend compatible with the IDO database.

![Icinga Web 2 Monitoring Module with Graphite](doc/res/monitoring-module-preview.png "Icinga Web 2 Monitoring Module with Graphite")

## License

Icinga Web 2 and the Icinga Web 2 documentation are licensed under the terms of the GNU
General Public License Version 2, you will find a copy of this license in the
COPYING file included in the source package.

## Installation

For installing Icinga Web 2 please check the [installation chapter](https://icinga.com/docs/icingaweb2/latest/doc/02-Installation/)
in the documentation.

## Documentation

The documentation is located in the [doc/](doc/) directory and also available
on [icinga.com/docs](https://icinga.com/docs/icingaweb2/latest/).

## Support

Check the [project website](https://icinga.com) for status updates. Join the
[community channels](https://icinga.com/community/) for questions
or ask an Icinga partner for [professional support](https://icinga.com/support/).

## Contributing

There are many ways to contribute to Icinga -- whether it be sending patches,
testing, reporting bugs, or reviewing and updating the documentation. Every
contribution is appreciated!

Please continue reading in the [contributing chapter](CONTRIBUTING.md).

### Security Issues

For reporting security issues please visit [this page](https://icinga.com/contact/security/).
